@@ -50,3 +50,26 @@ def test_basic_timeout():
     assert got_cancel.is_set()
     stop_event.set()  # Don't leave the thread hanging
     tracker.join()  # Make sure it exited
+
+
+def test_multiple_timeouts():
+    stop_event = Event()
+    tracker = TimeoutTracker(stop_event)
+    tracker.daemon = True
+    tracker.start()
+
+    t_1 = Event()
+    t_2 = Event()
+
+    tracker.add_timeout(timedelta(seconds=1), t_1.set)
+    tracker.add_timeout(timedelta(seconds=10), t_2.set)
+
+    assert not t_1.is_set()
+    assert not t_2.is_set()
+
+    time.sleep(2)
+    assert t_1.is_set()
+    assert not t_2.is_set()
+
+    stop_event.set()  # Don't leave the thread hanging
+    tracker.join()  # Make sure it exited
